<!-- warning: Please don't edit this file. It was automatically generated. -->

# winrt-Windows.ApplicationModel.AppService

Windows Runtime (WinRT) APIs for for the `Windows.ApplicationModel.AppService` namespace.

This package provides the `winrt.windows.applicationmodel.appservice` module.
